@@ -27,10 +27,10 @@ from __future__ import unicode_literals
 import copy
 import operator
 from itertools import chain
+from collections import OrderedDict
 
 from . import message
 
-from .collections import OrderedDict
 from .message import Position
 from .utils import to_underscores
 
@@ -109,7 +109,9 @@ in contrast to the other create_type() functions."""
                        ctype=fundamental.ctype)
         if gtype_name == 'GHashTable':
             return Map(TYPE_ANY, TYPE_ANY, gtype_name=gtype_name)
-        elif gtype_name in ('GArray', 'GPtrArray', 'GByteArray'):
+        elif gtype_name == 'GByteArray':
+            return Array('GLib.ByteArray', TYPE_UINT8, gtype_name=gtype_name)
+        elif gtype_name in ('GArray', 'GPtrArray'):
             return Array('GLib.' + gtype_name[1:], TYPE_ANY,
                          gtype_name=gtype_name)
         elif gtype_name == 'GStrv':
@@ -307,8 +309,6 @@ type_names['int32_t'] = TYPE_INT32
 type_names['uint32_t'] = TYPE_UINT32
 type_names['int64_t'] = TYPE_INT64
 type_names['uint64_t'] = TYPE_UINT64
-# C99 stdbool
-type_names['bool'] = TYPE_BOOLEAN
 
 # A few additional GLib type aliases
 type_names['guchar'] = TYPE_UINT8
@@ -569,7 +569,8 @@ class Node(Annotated):
 (namespace, name) pair.  When combined with a ., this is called a
 GIName.  It's possible for nodes to contain or point to other nodes."""
 
-    c_name = property(lambda self: self.namespace.name + self.name)
+    c_name = property(lambda self: self.namespace.name + self.name if self.namespace else
+                      self.name)
     gi_name = property(lambda self: '%s.%s' % (self.namespace.name, self.name))
 
     def __init__(self, name=None):
