@@ -119,7 +119,7 @@ class CCompiler(object):
         if os.name == 'nt':
             runtime_path_envvar = ['LIB', 'PATH']
         else:
-            runtime_path_envvar = ['LD_LIBRARY_PATH', 'DYLD_LIBRARY_PATH']
+            runtime_path_envvar = ['LD_LIBRARY_PATH', 'DYLD_FALLBACK_LIBRARY_PATH']
             # Search the current directory first
             # (This flag is not supported nor needed for Visual C++)
             args.append('-L.')
@@ -280,8 +280,6 @@ class CCompiler(object):
         else:
             libtool = utils.get_libtool_command(options)
             if libtool:
-                if os.name == 'nt':
-                    args.append(utils.which(os.environ.get('SHELL', 'sh.exe')))
                 args.extend(libtool)
                 args.append('--mode=execute')
             args.extend([os.environ.get('DLLTOOL', 'dlltool.exe'), '--identify'])
@@ -356,10 +354,7 @@ class CCompiler(object):
         return shlibs
 
     def check_is_msvc(self):
-        if isinstance(self.compiler, MSVCCompiler):
-            return True
-        else:
-            return False
+        return isinstance(self.compiler, MSVCCompiler)
 
     # Private APIs
     def _set_cpp_options(self, options):
