@@ -18,17 +18,27 @@
 # 02110-1301, USA.
 #
 
+from __future__ import absolute_import
+from __future__ import division
+from __future__ import print_function
+from __future__ import unicode_literals
+
 import os
+import sys
 import argparse
 
+import giscanner
 from .docwriter import DocWriter
 from .sectionparser import generate_sections_file, write_sections_file
 from .transformer import Transformer
 
+FORMATS = ('mallard', 'sections')
+
 
 def doc_main(args):
     parser = argparse.ArgumentParser()
-
+    parser.add_argument('--version', action='version',
+                      version='%(prog)s ' + giscanner.__version__)
     parser.add_argument("girfile")
     parser.add_argument("-o", "--output",
                       action="store", dest="output",
@@ -37,12 +47,16 @@ def doc_main(args):
                       action="store", dest="language",
                       default="c",
                       help="Output language")
+    parser.add_argument("-f", "--format",
+                        action="store", dest="format",
+                        choices=FORMATS, default=FORMATS[0],
+                        help="Output format")
     parser.add_argument("-I", "--add-include-path",
                       action="append", dest="include_paths", default=[],
                       help="include paths for other GIR files")
     parser.add_argument("-s", "--write-sections-file",
-                      action="store_true", dest="write_sections",
-                      help="Generate and write out a sections file")
+                        action="store_const", dest="format", const="sections",
+                        help="Backwards-compatible equivalent to -f sections")
 
     args = parser.parse_args(args[1:])
     if not args.output:
@@ -57,14 +71,13 @@ def doc_main(args):
     extra_include_dirs.extend(args.include_paths)
     transformer = Transformer.parse_from_gir(args.girfile, extra_include_dirs)
 
-    if args.write_sections:
+    if args.format == 'sections':
         sections_file = generate_sections_file(transformer)
 
-        fp = open(args.output, 'w')
-        write_sections_file(fp, sections_file)
-        fp.close()
+        with open(args.output, 'w') as fp:
+            write_sections_file(fp, sections_file)
     else:
-        writer = DocWriter(transformer, args.language)
+        writer = DocWriter(transformer, args.language, args.format)
         writer.write(args.output)
 
     return 0
