@@ -330,6 +330,7 @@ class MainTransformer(object):
         # might lose the ctype from the original node.
         if type_node is not None:
             result.ctype = type_node.ctype
+            result.complete_ctype = type_node.complete_ctype
         return result
 
     def _get_position(self, func, param):
@@ -360,14 +361,11 @@ class MainTransformer(object):
                 message.warn("invalid (element-type) for a GPtrArray, "
                              "must be a pointer", annotations.position)
 
-        # GByteArrays have (element-type) guint8 by default
-        if array_type == ast.Array.GLIB_BYTEARRAY:
-            if element_type == ast.TYPE_ANY:
-                array.element_type = ast.TYPE_UINT8
-            elif element_type not in [ast.TYPE_UINT8, ast.TYPE_INT8, ast.TYPE_CHAR]:
-                message.warn("invalid (element-type) for a GByteArray, "
-                             "must be one of guint8, gint8 or gchar",
-                             annotations.position)
+        if (array_type == ast.Array.GLIB_BYTEARRAY
+        and element_type not in [ast.TYPE_UINT8, ast.TYPE_INT8, ast.TYPE_CHAR]):
+            message.warn("invalid (element-type) for a GByteArray, "
+                         "must be one of guint8, gint8 or gchar",
+                         annotations.position)
 
     def _apply_annotations_array(self, parent, node, annotations):
         element_type_options = annotations.get(ANN_ELEMENT_TYPE)
@@ -391,6 +389,7 @@ class MainTransformer(object):
 
         array_options = annotations.get(ANN_ARRAY)
         container_type = ast.Array(array_type, element_type_node, ctype=node.type.ctype,
+                                   complete_ctype=node.type.complete_ctype,
                                    is_const=node.type.is_const)
         if array_options.get(OPT_ARRAY_ZERO_TERMINATED, '0') == '0':
             container_type.zeroterminated = False
@@ -895,7 +894,7 @@ class MainTransformer(object):
             # the number of parameters (@foo) is the same or greater
             # than the number of signal parameters
             if len(block.params) > len(signal.parameters):
-                names = block.params.items()
+                names = [(k, v) for k, v in block.params.items()]
                 # Resolve real parameter names early, so that in later
                 # phase we can refer to them while resolving annotations.
                 for i, param in enumerate(signal.parameters):
