@@ -34,8 +34,10 @@ import subprocess
 import sys
 import tempfile
 import platform
+import shlex
 
-from giscanner import message
+import giscanner
+from giscanner import message, pkgconfig
 from giscanner.annotationparser import GtkDocCommentBlockParser
 from giscanner.ast import Include, Namespace
 from giscanner.dumper import compile_introspection_binary
@@ -101,7 +103,8 @@ def get_windows_option_group(parser):
 
 
 def _get_option_parser():
-    parser = optparse.OptionParser('%prog [options] sources')
+    parser = optparse.OptionParser('%prog [options] sources',
+                                   version='%prog ' + giscanner.__version__)
     parser.add_option('', "--quiet",
                       action="store_true", dest="quiet",
                       default=False,
@@ -285,7 +288,7 @@ def test_codegen(optstring,
 
 
 def process_options(output, allowed_flags):
-    for option in output.split():
+    for option in output:
         for flag in allowed_flags:
             if not option.startswith(flag):
                 continue
@@ -294,19 +297,11 @@ def process_options(output, allowed_flags):
 
 
 def process_packages(options, packages):
-    args = [os.environ.get('PKG_CONFIG', 'pkg-config'), '--cflags']
-    args.extend(packages)
-    output = subprocess.Popen(args,
-                              stdout=subprocess.PIPE).communicate()[0]
-    if output is None:
-        # the error output should have already appeared on our stderr,
-        # so we just exit
-        return 1
-    output = output.decode('ascii')
+    flags = pkgconfig.cflags(packages)
     # Some pkg-config files on Windows have options we don't understand,
     # so we explicitly filter to only the ones we need.
     options_whitelist = ['-I', '-D', '-U', '-l', '-L']
-    filtered_output = list(process_options(output, options_whitelist))
+    filtered_output = list(process_options(flags, options_whitelist))
     parser = _get_option_parser()
     pkg_options, unused = parser.parse_args(filtered_output)
     options.cpp_includes.extend([os.path.realpath(f) for f in pkg_options.cpp_includes])
@@ -380,10 +375,12 @@ see --identifier-prefix and --symbol-prefix.""")
 
 
 def create_transformer(namespace, options):
+    identifier_filter_cmd = shlex.split(options.identifier_filter_cmd)
+    symbol_filter_cmd = shlex.split(options.symbol_filter_cmd)
     transformer = Transformer(namespace,
                               accept_unprefixed=options.accept_unprefixed,
-                              identifier_filter_cmd=options.identifier_filter_cmd,
-                              symbol_filter_cmd=options.symbol_filter_cmd)
+                              identifier_filter_cmd=identifier_filter_cmd,
+                              symbol_filter_cmd=symbol_filter_cmd)
     transformer.set_include_paths(options.include_paths)
     if options.passthrough_gir or options.reparse_validate_gir:
         transformer.disable_cache()
@@ -494,6 +491,9 @@ def scanner_main(args):
     parser = _get_option_parser()
     (options, args) = parser.parse_args(args)
 
+    if options.verbose:
+        import distutils
+        distutils.log.set_threshold(distutils.log.DEBUG)
     if options.passthrough_gir:
         passthrough_gir(options.passthrough_gir, sys.stdout)
     if options.test_codegen:
@@ -531,9 +531,10 @@ def scanner_main(args):
     packages = set(options.packages)
     packages.update(transformer.get_pkgconfig_packages())
     if packages:
-        exit_code = process_packages(options, packages)
-        if exit_code:
-            return exit_code
+        try:
+            process_packages(options, packages)
+        except pkgconfig.PkgConfigError as e:
+            _error(str(e))
 
     ss = create_source_scanner(options, args)
 
