@@ -50,7 +50,7 @@ class Transformer(object):
     namespace = property(lambda self: self._namespace)
 
     def __init__(self, namespace, accept_unprefixed=False,
-                 identifier_filter_cmd='', symbol_filter_cmd=''):
+                 identifier_filter_cmd=None, symbol_filter_cmd=None):
         self._cachestore = CacheStore()
         self._accept_unprefixed = accept_unprefixed
         self._namespace = namespace
@@ -259,14 +259,14 @@ currently-scanned namespace is first."""
             proc = subprocess.Popen(self._symbol_filter_cmd,
                                     stdin=subprocess.PIPE,
                                     stdout=subprocess.PIPE,
-                                    stderr=subprocess.PIPE,
-                                    shell=True)
+                                    stderr=subprocess.PIPE)
             _name = name
             proc_name, err = proc.communicate(name.encode())
             if proc.returncode:
-                raise ValueError('filter: "%s" exited: %d with error: %s' %
+                raise ValueError('filter: %r exited: %d with error: %s' %
                                  (self._symbol_filter_cmd, proc.returncode, err))
             name = proc_name.decode('ascii')
+            name = name.strip()
 
         matches = []  # Namespaces which might contain this name
         unprefixed_namespaces = []  # Namespaces with no prefix, last resort
@@ -325,13 +325,12 @@ raise ValueError."""
             proc = subprocess.Popen(self._identifier_filter_cmd,
                                     stdin=subprocess.PIPE,
                                     stdout=subprocess.PIPE,
-                                    stderr=subprocess.PIPE,
-                                    shell=True)
+                                    stderr=subprocess.PIPE)
             proc_ident, err = proc.communicate(ident.encode())
             if proc.returncode:
-                raise ValueError('filter: "%s" exited: %d with error: %s' %
+                raise ValueError('filter: %r exited: %d with error: %s' %
                                  (self._identifier_filter_cmd, proc.returncode, err))
-            ident = proc_ident.decode('ascii')
+            ident = proc_ident.decode('ascii').strip()
 
         hidden = ident.startswith('_')
         if hidden:
@@ -455,7 +454,7 @@ raise ValueError."""
         func.add_symbol_reference(symbol)
         return func
 
-    def _create_source_type(self, source_type):
+    def _create_source_type(self, source_type, is_parameter=False):
         assert source_type is not None
         if source_type.type == CTYPE_VOID:
             value = 'void'
@@ -463,15 +462,19 @@ raise ValueError."""
             value = source_type.name
         elif source_type.type == CTYPE_TYPEDEF:
             value = source_type.name
+        elif (source_type.type == CTYPE_POINTER or
+                # Array to pointer adjustment as per 6.7.6.3.
+                # This is performed only on the outermost array,
+                # so we don't forward is_parameter.
+                (source_type.type == CTYPE_ARRAY and is_parameter)):
+            value = self._create_source_type(source_type.base_type) + '*'
         elif source_type.type == CTYPE_ARRAY:
             return self._create_source_type(source_type.base_type)
-        elif source_type.type == CTYPE_POINTER:
-            value = self._create_source_type(source_type.base_type) + '*'
         else:
             value = 'gpointer'
         return value
 
-    def _create_complete_source_type(self, source_type):
+    def _create_complete_source_type(self, source_type, is_parameter=False):
         assert source_type is not None
 
         const = (source_type.type_qualifier & TYPE_QUALIFIER_CONST)
@@ -491,16 +494,21 @@ raise ValueError."""
                 value = 'const ' + value
             if volatile:
                 value = 'volatile ' + value
-        elif source_type.type == CTYPE_ARRAY:
-            return self._create_complete_source_type(source_type.base_type)
-        elif source_type.type == CTYPE_POINTER:
+            return value
+        elif (source_type.type == CTYPE_POINTER or
+                # Array to pointer adjustment as per 6.7.6.3.
+                # This is performed only on the outermost array,
+                # so we don't forward is_parameter.
+                (source_type.type == CTYPE_ARRAY and is_parameter)):
             value = self._create_complete_source_type(source_type.base_type) + '*'
             # TODO: handle pointer to function as a special case?
             if const:
                 value += ' const'
             if volatile:
                 value += ' volatile'
-
+            return value
+        elif source_type.type == CTYPE_ARRAY:
+            return self._create_complete_source_type(source_type.base_type)
         else:
             if const:
                 value = 'gconstpointer'
@@ -510,8 +518,6 @@ raise ValueError."""
                 value = 'volatile ' + value
             return value
 
-        return value
-
     def _create_parameters(self, symbol, base_type):
         for i, child in enumerate(base_type.child_list):
             yield self._create_parameter(symbol, i, child)
@@ -651,8 +657,8 @@ raise ValueError."""
         return canonical
 
     def _create_type_from_base(self, source_type, is_parameter=False, is_return=False):
-        ctype = self._create_source_type(source_type)
-        complete_ctype = self._create_complete_source_type(source_type)
+        ctype = self._create_source_type(source_type, is_parameter=is_parameter)
+        complete_ctype = self._create_complete_source_type(source_type, is_parameter=is_parameter)
         const = ((source_type.type == CTYPE_POINTER) and
                  (source_type.base_type.type_qualifier & TYPE_QUALIFIER_CONST))
         return self.create_type_from_ctype_string(ctype, is_const=const,
@@ -668,9 +674,12 @@ raise ValueError."""
                 name = base
             return ast.List(name, ast.TYPE_ANY, ctype=ctype,
                         is_const=is_const, complete_ctype=complete_ctype)
-        elif base in ('GArray', 'GPtrArray', 'GByteArray',
-                      'GLib.Array', 'GLib.PtrArray', 'GLib.ByteArray',
-                      'GObject.Array', 'GObject.PtrArray', 'GObject.ByteArray'):
+        elif base in ('GByteArray', 'GLib.ByteArray', 'GObject.ByteArray'):
+            return ast.Array('GLib.ByteArray', ast.TYPE_UINT8, ctype=ctype,
+                         is_const=is_const, complete_ctype=complete_ctype)
+        elif base in ('GArray', 'GPtrArray',
+                      'GLib.Array', 'GLib.PtrArray',
+                      'GObject.Array', 'GObject.PtrArray'):
             if '.' in base:
                 name = 'GLib.' + base.split('.', 1)[1]
             else:
@@ -688,6 +697,15 @@ raise ValueError."""
         canonical = self._canonicalize_ctype(ctype)
         base = canonical.replace('*', '')
 
+        # While gboolean and _Bool are distinct types, they used to be treated
+        # by scanner as exactly the same one. In general this is incorrect
+        # because of different ABI, but this usually works fine,
+        # so for backward compatibility lets continue for now:
+        # https://gitlab.gnome.org/GNOME/gobject-introspection/merge_requests/24#note_92792
+        if canonical == '_Bool':
+            canonical = 'gboolean'
+            base = canonical
+
         # Special default: char ** -> ast.Array, same for GStrv
         if (is_return and canonical == 'utf8*') or base == 'GStrv':
             bare_utf8 = ast.TYPE_STRING.clone()
