@@ -27,6 +27,8 @@ import re
 import os
 import subprocess
 import platform
+import shutil
+import time
 
 
 _debugflags = None
@@ -159,7 +161,7 @@ def get_libtool_command(options):
         libtool_cmd = 'glibtool'
     try:
         subprocess.check_call([libtool_cmd, '--version'],
-                              stdout=open('/dev/null', 'w'))
+                              stdout=open(os.devnull, 'w'))
     except (subprocess.CalledProcessError, OSError):
         # If libtool's not installed, assume we don't need it
         return None
@@ -184,6 +186,10 @@ def cflag_real_include_path(cflag):
     return "-I" + os.path.realpath(cflag[2:])
 
 
+def host_os():
+    return os.environ.get("GI_HOST_OS", os.name)
+
+
 def which(program):
     def is_exe(fpath):
         return os.path.isfile(fpath) and os.access(fpath, os.X_OK)
@@ -228,7 +234,7 @@ def makedirs(name, mode=0o777, exist_ok=False):
     if head and tail and not os.path.exists(head):
         try:
             makedirs(head, mode, exist_ok)
-        except OSError as e:
+        except (IOError, OSError) as e:
             # be happy if someone already created the path
             if e.errno != errno.EEXIST:
                 raise
@@ -236,7 +242,7 @@ def makedirs(name, mode=0o777, exist_ok=False):
             return
     try:
         os.mkdir(name, mode)
-    except OSError as e:
+    except (IOError, OSError) as e:
         if not exist_ok or e.errno != errno.EEXIST or not os.path.isdir(name):
             raise
 
@@ -287,3 +293,26 @@ def get_system_data_dirs():
         xdg_data_dirs.append('/usr/share')
 
     return xdg_data_dirs
+
+
+def rmtree(*args, **kwargs):
+    '''
+    A variant of shutil.rmtree() which waits and tries again in case one of
+    the files in the directory tree can't be deleted.
+
+    This can be the case if a file is still in use by some process,
+    for example a Virus scanner on Windows scanning .exe files when they are
+    created.
+    '''
+
+    tries = 3
+    for i in range(1, tries + 1):
+        try:
+            shutil.rmtree(*args, **kwargs)
+        except OSError:
+            if i == tries:
+                raise
+            time.sleep(i)
+            continue
+        else:
+            return
