@@ -165,7 +165,7 @@ _GI_TEST_EXTERN
 char *regress_test_array_gtype_in (int n_types, GType *types);
 
 _GI_TEST_EXTERN
-char **regress_test_strv_out_container (void);
+const char **regress_test_strv_out_container (void);
 
 _GI_TEST_EXTERN
 char **regress_test_strv_out (void);
@@ -174,7 +174,7 @@ _GI_TEST_EXTERN
 const char * const * regress_test_strv_out_c (void);
 
 _GI_TEST_EXTERN
-void   regress_test_strv_outarg (char ***retp);
+void   regress_test_strv_outarg (const char ***retp);
 
 _GI_TEST_EXTERN
 int regress_test_array_fixed_size_int_in (int *ints);
@@ -376,7 +376,8 @@ typedef enum
   REGRESS_TEST_VALUE1,
   REGRESS_TEST_VALUE2,
   REGRESS_TEST_VALUE3 = -1,
-  REGRESS_TEST_VALUE4 = '0'
+  REGRESS_TEST_VALUE4 = '0',
+  REGRESS_TEST_VALUE5
 } RegressTestEnum;
 
 typedef enum
@@ -422,6 +423,13 @@ typedef enum
   REGRESS_TEST_EVALUE3 = '0'
 } RegressTestEnumNoGEnum;
 
+/**
+ * REGRESS_TEST_EVALUE_DEPRECATED:
+ *
+ * Scanner used to replace %REGRESS_TEST_EVALUE1 with %REGRESS_TEST_EVALUE_DEPRECATED.
+ */
+#define REGRESS_TEST_EVALUE_DEPRECATED REGRESS_TEST_EVALUE1
+
 _GI_TEST_EXTERN
 const gchar * regress_test_enum_param(RegressTestEnum e);
 
@@ -771,6 +779,7 @@ struct _RegressTestObj
   double some_double;
   char* string;
   GType gtype;
+  gint name_conflict;
 
   /* < private > */
   void (*function_ptr) (void);
@@ -830,6 +839,9 @@ void       regress_test_obj_emit_sig_with_uint64 (RegressTestObj *obj);
 _GI_TEST_EXTERN
 void       regress_test_obj_emit_sig_with_array_len_prop (RegressTestObj *obj);
 
+_GI_TEST_EXTERN
+void       regress_test_obj_emit_sig_with_inout_int (RegressTestObj *obj);
+
 _GI_TEST_EXTERN
 int        regress_test_obj_instance_method (RegressTestObj *obj);
 
@@ -940,6 +952,9 @@ void regress_test_obj_not_nullable_element_typed_gpointer_in (RegressTestObj *ob
                                                               gpointer        input,
                                                               guint           count);
 
+_GI_TEST_EXTERN
+void regress_test_obj_name_conflict (RegressTestObj *obj);
+
 /* inheritance */
 #define REGRESS_TEST_TYPE_SUB_OBJ           (regress_test_sub_obj_get_type ())
 #define REGRESS_TEST_SUB_OBJECT(object)     (G_TYPE_CHECK_INSTANCE_CAST ((object), REGRESS_TEST_TYPE_SUB_OBJ, RegressTestSubObj))
@@ -1184,6 +1199,9 @@ struct _RegressTestInterfaceIface {
 _GI_TEST_EXTERN
 GType regress_test_interface_get_type (void) G_GNUC_CONST;
 
+_GI_TEST_EXTERN
+void regress_test_interface_emit_signal (RegressTestInterface *self);
+
 /* gobject with non-standard prefix */
 #define REGRESS_TEST_TYPE_WI_802_1X              (regress_test_wi_802_1x_get_type ())
 #define REGRESS_TEST_WI_802_1X(object)        (G_TYPE_CHECK_INSTANCE_CAST ((object), REGRESS_TEST_TYPE_WI_802_1X, RegressTestWi8021x))
@@ -1393,7 +1411,7 @@ typedef struct {
 
 _GI_TEST_EXTERN
 void regress_like_xkl_config_item_set_name (RegressLikeXklConfigItem *self,
-                                            const char *name);
+                                            char const *name);
 
 #define REGRESS_UTF8_CONSTANT "const \xe2\x99\xa5 utf8"
 
