@@ -7,6 +7,7 @@ import unittest
 import tempfile
 import os
 import sys
+import textwrap
 
 if sys.version_info.major < 3:
     import __builtin__ as builtins
@@ -15,12 +16,6 @@ else:
 
 
 os.environ['GI_SCANNER_DISABLE_CACHE'] = '1'
-path = os.getenv('UNINSTALLED_INTROSPECTION_SRCDIR', None)
-assert path is not None
-sys.path.insert(0, path)
-
-# Not correct, but enough to get the tests going uninstalled
-builtins.__dict__['DATADIR'] = path
 
 from giscanner import ast
 from giscanner.sourcescanner import SourceScanner
@@ -46,12 +41,16 @@ def load_namespace_from_source_string(namespace, source):
 
 
 class TestIdentifierFilter(unittest.TestCase):
-    def test_underscore_t_sed_filter(self):
-        cmd = r"sed " \
-              r"-e 's/^test_t$/TestContext/' " \
-              r"-e 's/\(.*\)_t$/\1/' " \
-              r"-e 's/^test_/Test_/' " \
-              r"-e 's/_\([a-z]\)/" + '\\u' + r"\1/g'"
+    def test_underscore_t_identifier_filter(self):
+        cmd = [sys.executable, '-c', textwrap.dedent("""
+            import sys, re
+            for line in sys.stdin:
+                line = re.sub(r"^test_t$", "TestContext", line)
+                line = re.sub(r"_t$", "", line)
+                line = re.sub(r"^test_", "Test_", line)
+                line = re.sub(r"_([a-z])", lambda m: m.group(1).title(),
+                              line)
+                sys.stdout.write(line)""")]
 
         namespace = ast.Namespace('Test', '1.0')
         xformer = Transformer(namespace, identifier_filter_cmd=cmd)
@@ -63,16 +62,29 @@ class TestIdentifierFilter(unittest.TestCase):
         self.assertEqual(xformer.strip_identifier('test_foo_tart'), 'FooTart')
 
     def test_invalid_command(self):
-        cmd = r'this-is-not-a-real-command'
+        cmd = ['this-is-not-a-real-command']
+        namespace = ast.Namespace('Test', '1.0')
+        xformer = Transformer(namespace, identifier_filter_cmd=cmd)
+        self.assertRaises(OSError, xformer.strip_identifier, 'test_t')
+
+    def test_invalid_argument(self):
+        cmd = [sys.executable, '--not-a-valid-argument']
         namespace = ast.Namespace('Test', '1.0')
         xformer = Transformer(namespace, identifier_filter_cmd=cmd)
         self.assertRaises(ValueError, xformer.strip_identifier, 'test_t')
 
-    def test_invalid_argument(self):
-        cmd = r'sed --not-a-valid-argument'
+
+class TestSymbolFilter(unittest.TestCase):
+
+    def test_split_csymbol(self):
+        cmd = [
+            sys.executable, '-c',
+            'import sys; sys.stdout.write("test_" + sys.stdin.read())']
         namespace = ast.Namespace('Test', '1.0')
-        xformer = Transformer(namespace, identifier_filter_cmd=cmd)
-        self.assertRaises(ValueError, xformer.strip_identifier, 'test_t')
+        xformer = Transformer(namespace, symbol_filter_cmd=cmd)
+
+        self.assertEqual(
+            xformer.split_csymbol('foo_bar_quux')[1], "foo_bar_quux")
 
 
 class TestStructTypedefs(unittest.TestCase):
